helga-alias
===========

This plugin will track nick aliases, and provide known aliases for other plugins

Usage::

  <bigjust> !alias
  <helga> Known Aliases:
  <helga> jcaratzas bigjust jcaratza1
  <helga> zero_cool

  <bigjust> !alias add zero_cool crash_override
  <helga> added.

  <bigjust> !alias zero_cool
  <helga> zero_cool crash_override

License
-------

Copyright (c) 2017 #n

GPLv3 Licensed
